==> cobs-0.03.tgz: cbos-0.03/ref.php <==
<?
function ref($bibletxt,$engs,$ochap)
{
    require("config.php");
    $tmp=$bibletxt;
    $bibletxt="";
    //$db_conn=pg_connect("host=localhost dbname=tjm password=123");
    $db_conn=pg_connect("host=localhost dbname=$DBNAME");
    while (!(($pt=strpos($tmp,"#"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	$ok=htmlspecialchars($ok1);
        $bibletxt=$bibletxt.$ok;
        /****** oO]sX|X{u|vҥHnBz@U *****/
        $ttmpt=substr($tmp,$pt);
        $pt1=strpos($ttmpt,"|");
	$pt1=$pt1+$pt;
        if ($pt1==0)
        {
           echo "error in bible reference parsing $tmp <br>";
           return;
        }
 	/**** Add process to strong num ***/
	$refstr=substr($tmp,$pt+1,$pt1-$pt-1);
	//$refstr=substr($tmp,$pt,$pt1-$pt-1);
	//$showstr=substr($tmp,$pt,$pt1-$pt-1);
	//echo "pt=$pt refstr=$refstr<br>\n";
	/**** process refstr ****/
        //echo "pt1=$pt1 pt=$pt" ;
	$wtok=split("[|;]",$refstr); //ޥθ
	$ii=count($wtok);
	$book=$engs;
	$chap=0;
	$sec=0;
	for ($i=0;$i<$ii;$i++)
	{
		$wtok[$i]=trim($wtok[$i]);
		//echo $wtok[$i];
		$btok=array("","","");
		$cnt=0;
		$stok=strtok($wtok[$i]," :;|");
		while (!($stok === FALSE))
		{
		    if (strlen($stok)) //ŦrAѨMD
                    {
		    	$btok[$cnt]=$stok;
		    	$cnt=$cnt+1;
                    }
		    $stok=strtok(" :\n;|");

		}
		switch ($cnt)
		{
		 case 4: //# 2Ch 14:1-16:14
			$book=trim($btok[0]);
                        $chap=(int)$btok[1];
			$ctmp=split("-",$btok[2]); //} 1-16
			$sec=$ctmp[0];
			$chap2=$ctmp[1];
                        $sec2=$btok[3];
			break;
		 case 3:  //#mt 1:2 Ӥ@G`
			//P_@U OO # 14:1-16:14
			if (strstr($btok[1],"-"))
			{
                          $chap=(int)$btok[0];
			  $ctmp=split("-",$btok[1]); //} 1-16
			  $sec=$ctmp[0];
			  $chap2=$ctmp[1];
                          $sec2=$btok[2];
			  $cnt=4; //Pe@تp
			}
			else
			{
			   $book=trim($btok[0]);
                           $chap=(int)$btok[1];
                           $sec=$btok[2];
			}
			break;
		 case 2: //#1:2 @G`
                        $chap=(int)$btok[0];
                        $sec=$btok[1];
			break;
		 case 1: //#1 Ĥ@`  Ĥ@
			if ($ochap==0) $chap=$btok[0];
			else 
			{
                        	$chap=$ochap;
                        	$sec=$btok[0];
			}
			break;
		/*******
		default: 
			echo "Error in parser btok, Cnt= $cnt";
		*******/
		}
	      if (Ord($book)<128)
	      {
	        $QUERY="select chineses,engs from main where sengs = '$book' or engs='$book'";
 		/******** }ldƮw ********/
 		$resultr=pg_exec($db_conn,$QUERY);
 		if (!$resultr){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 		}
 		if (!$resultr){
                        echo "Ʈwd߿~AO $QUERY !";
                        return "";
 		}
		$numrow=pg_NumRows($resultr);
		if ($numrow!=1)
		{
                        echo "@@dX $numrow AޥθƦDI$QUERY";
                        return "";
		}
		 $ARAW=pg_fetch_row($resultr,0); //Ū@O
        	 pg_Close($db_conn);
		$ARAW[0]=trim($ARAW[0]);
		 if ($cnt==4)
    		 $bibletxt=$bibletxt." <a href=\"read.php?VERSION=unv&TABFLAG=1&chineses=$ARAW[0]&chap=$chap&sec=$sec&chap2=$chap2&sec2=$sec2\">$wtok[$i]</a> ";
		 elseif ($cnt>4)
    		 $bibletxt=$bibletxt.$wtok[$i];
		 else
    		 $bibletxt=$bibletxt." <a href=\"read.php?VERSION=unv&TABFLAG=1&chineses=$ARAW[0]&chap=$chap&sec=$sec\">$wtok[$i]</a> ";
	     } //if Ord ˬdO_^
	     else //աI
		{
		 if ($cnt==4)
    		 $bibletxt=$bibletxt." <a href=\"read.php?VERSION=unv&TABFLAG=1&chineses=$book&chap=$chap&sec=$sec&chap2=$chap2&sec2=$sec2\">$wtok[$i]</a> ";
		 else
    		 $bibletxt=$bibletxt." <a href=\"read.php?VERSION=unv&TABFLAG=1&chineses=$book&chap=$chap&sec=$sec\">$wtok[$i]</a> ";
		}
		//echo "book=$book chap=$chap sec=$sec <br>\n"; 
	}
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+1);
	//echo "tmp=$tmp";
    }
    $bibletxt=$bibletxt.$tmp;
    return $bibletxt;
}

==> cobs-0.05.tgz: cbos-0.05/ref.php <==
<?
function ref($bibletxt,$engs,$ochap,$db_conn)
{
    require("config.php");
    //require("dbconfig.php");
    $tmp=$bibletxt;
    $bibletxt="";
    while (!(($pt=strpos($tmp,"#"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	$ok=htmlspecialchars($ok1);
        $bibletxt=$bibletxt.$ok;
        /****** oO]sX|X{u|vҥHnBz@U *****/
        $ttmpt=substr($tmp,$pt);
        $pt1=strpos($ttmpt,"|");
	$pt1=$pt1+$pt;
        if ($pt1==0)
        {
           echo "error in bible reference parsing $tmp <br>";
           return;
        }
 	/**** Add process to strong num ***/
	$refstr=substr($tmp,$pt+1,$pt1-$pt-1);
	$refstr=ereg_replace("with","",$refstr); //onwith
	/**** process refstr ****/
        //echo "pt1=$pt1 pt=$pt" ;
	$wtok=split("[|;]",$refstr); //ޥθ
	$ii=count($wtok);
	$book=$engs;
	$chap=0;
	$sec=0;
	for ($i=0;$i<$ii;$i++)
	{
		$wtok[$i]=trim($wtok[$i]);
		//echo $wtok[$i];
		$btok=array("","","");
		$cnt=0;
		$stok=strtok($wtok[$i]," :;|");
		while (!($stok === FALSE))
		{
		    if (strlen($stok)) //ŦrAѨMD
                    {
		    	$btok[$cnt]=$stok;
		    	$cnt=$cnt+1;
                    }
		    $stok=strtok(" :\n;|");

		}
		switch ($cnt)
		{
		 case 4: //# 2Ch 14:1-16:14
			$book=trim($btok[0]);
                        $chap=(int)$btok[1];
			$ctmp=split("-",$btok[2]); //} 1-16
			$sec=$ctmp[0];
			$chap2=$ctmp[1];
                        $sec2=$btok[3];
			break;
		 case 3:  //#mt 1:2 Ӥ@G`
			//P_@U OO # 14:1-16:14
			if (strstr($btok[1],"-"))
			{
                          $chap=(int)$btok[0];
			  $ctmp=split("-",$btok[1]); //} 1-16
			  $sec=$ctmp[0];
			  $chap2=$ctmp[1];
                          $sec2=$btok[2];
			  $cnt=4; //Pe@تp
			}
			else
			{
			   $book=trim($btok[0]);
                           $chap=(int)$btok[1];
                           $sec=$btok[2];
			}
			break;
		 case 2: //#1:2 @G`
                        $chap=(int)$btok[0];
                        $sec=$btok[1];
			break;
		 case 1: //#1 Ĥ@`  Ĥ@
			if ($ochap==0) $chap=$btok[0];
			else 
			{
                        	$chap=$ochap;
                        	$sec=$btok[0];
			}
			break;
		/*******
		default: 
			echo "Error in parser btok, Cnt= $cnt";
		*******/
		}
	      if (Ord($book)<128)
	      {
	        $QUERY="select chineses,engs from main where sengs = '$book' or engs='$book'";
 		/******** }ldƮw ********/
 		$resultr=db_exec($db_conn,$QUERY);
 		if (!$resultr){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 		}
 		if (!$resultr){
                        echo "Ʈwd߿~AO $QUERY !";
                        return "";
 		}
		$numrow=db_NumRows($resultr);
		if ($numrow!=1)
		{
                        echo "@@dX $numrow AޥθƦDI$QUERY";
                        return "";
		}
		 $ARAW=db_fetch_row($resultr,0); //Ū@O
		$ARAW[0]=trim($ARAW[0]);
		 if ($cnt==4)
    		 $bibletxt=$bibletxt." <a href=\"read.php?VERSION=unv&TABFLAG=1&chineses=$ARAW[0]&chap=$chap&sec=$sec&chap2=$chap2&sec2=$sec2\">$wtok[$i]</a> ";
		 elseif ($cnt>4)
    		 $bibletxt=$bibletxt.$wtok[$i];
		 else
    		 $bibletxt=$bibletxt." <a href=\"read.php?VERSION=unv&TABFLAG=1&chineses=$ARAW[0]&chap=$chap&sec=$sec\">$wtok[$i]</a> ";
	     } //if Ord ˬdO_^
	     else //աI
		{
		 if ($cnt==4)
    		 $bibletxt=$bibletxt." <a href=\"read.php?VERSION=unv&TABFLAG=1&chineses=$book&chap=$chap&sec=$sec&chap2=$chap2&sec2=$sec2\">$wtok[$i]</a> ";
		 else
    		 $bibletxt=$bibletxt." <a href=\"read.php?VERSION=unv&TABFLAG=1&chineses=$book&chap=$chap&sec=$sec\">$wtok[$i]</a> ";
		}
		//echo "book=$book chap=$chap sec=$sec <br>\n"; 
	}
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+1);
	//echo "tmp=$tmp";
    }
    $bibletxt=$bibletxt.$tmp;
    return $bibletxt;
}
